#
# spec file for package python-audiomate
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-audiomate
Version:        6.0.0
Release:        5.1
Summary:        A library for working with audio datasets
License:        MIT
URL:            https://github.com/ynop/audiomate
Source0:        https://files.pythonhosted.org/packages/source/a/audiomate/audiomate-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PGet >= 0.5.0
Requires:       python-audioread >= 2.1.8
Requires:       python-h5py >= 2.10.0
Requires:       python-intervaltree >= 3.0.2
Requires:       python-librosa >= 0.7.2
Requires:       python-networkx >= 2.4
Requires:       python-numba >= 0.49.1
Requires:       python-numpy >= 1.18.1
Requires:       python-requests >= 2.23.0
Requires:       python-scipy >= 1.4.1
Requires:       python-sox >= 1.3.7
BuildArch:      noarch
%python_subpackages

%description
Audiomate is a library providing datastructures for accessing/loading
audio datasets.

%prep
%setup -q -n audiomate-%{version}
sed -i "s/'pytest-runner'//" setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Test files not present
# They would be too big
# %%check
# echo "" > tests/__init__.py
# %%{python_expand export PYTHONPATH=%%{buildroot}%%{$python_sitelib}
# py.test-%%{$python_bin_suffix} .}

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/audiomate
%{python_sitelib}/bench
%{python_sitelib}/audiomate-%{version}.dist-info

%changelog
* Fri May  9 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Sat May 27 2023 Dirk Müller <dmueller@suse.com>
- reenable python 3.11 build (numba available now)
* Tue Apr  4 2023 Daniel Garcia <daniel.garcia@suse.com>
- Skip python311, python-numba doesn't support python 3.11 yet.
* Fri May 28 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Tue Nov 10 2020 Marketa Machova <mmachova@suse.com>
- Update to 6.0.0
  * Drop support of Python 3.5 because a required dependency (llvmlite)
    does not support it anymore.
  * Setup consistent way for logging.
* Tue Jul  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 5.0.2
  * Many new features and performance improvements, see upstream changelog
  Breaking:
  * Changed :class:`audiomate.corpus.validation.InvalidItemsResult'
    to use it not only for Utterances, but also for Tracks for example.
  * Refactoring and addition of splitting functions in the
    :class:`audiomate.corpus.subset.Splitter`.
  * For utterances and labels -1 was used for representing that the end
    is the same as the end of the parent utterance/track. In order to
    prevent -1 checks in different methods/places float('inf') is now used.
    This makes it easier to implement stuff like label overlapping.
  * :class:`audiomate.annotations.LabelList` is now backed by an interval-tree
    instead of a simple list. Therefore the labels have no fixed order anymore.
    The interval-tree provides functionality for operations like merging,
    splitting, finding overlaps with much lower code complexity.
  * Removed module :mod:`audiomate.annotations.label_cleaning`, since those
    methods are available on :class:`audiomate.annotations.LabelList` directly.
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 3.0.0
  + Breaking Changes
  * Moved label-encoding to its own module (audiomate.encoding). It now provides the processing of full corpora and store it in containers.
  * Moved audiomate.feeding.PartitioningFeatureIterator to the audiomate.feeding module.
  * Added audiomate.containers.AudioContainer to store audio tracks in a single file. All container classes are now in a separate module audiomate.containers.
  * Corpus now contains Tracks not Files anymore. This makes it possible to different kinds of audio sources. Audio from a file is now included using audiomate.tracks.FileTrack. New is the audiomate.tracks.ContainerTrack, which reads data stored in a container.
  * The audiomate.corpus.io.DefaultReader and the audiomate.corpus.io.DefaultWriter now load and store tracks, that are stored in a container.
  * All functionality regarding labels was moved to its own module audiomate.annotations.
  * The class audiomate.tracks.Utterance was moved to the tracks module.
  + New Features
  * Introducing the audiomate.feeding module. It provides different tools for accessing container data. Via a audiomate.feeding.Dataset data can be accessed by indices. With a audiomate.feeding.DataIterator one can easily iterate over data, such as frames.
  * Added processing steps for computing Onset-Strength (audiomate.processing.pipeline.OnsetStrength)) and Tempogram (audiomate.processing.pipeline.Tempogram)).
  * Introduced audiomate.corpus.validation module, that is used to validate a corpus.
  * Added reader (audiomate.corpus.io.SWCReader) for the SWC corpus. But it only works for the prepared corpus.
  * Added function (audiomate.corpus.utils.label_cleaning.merge_consecutive_labels_with_same_values()) for merging consecutive labels with the same value
  * Added downloader (audiomate.corpus.io.GtzanDownloader) for the GTZAN Music/Speech.
  * Added audiomate.corpus.assets.Label.tokenized() to get a list of tokens from a label. It basically splits the value and trims whitespace.
  * Added methods on audiomate.corpus.CorpusView, audiomate.corpus.assets.Utterance and audiomate.corpus.assets.LabelList to get a set of occurring tokens.
  * Added audiomate.encoding.TokenOrdinalEncoder to encode labels of an utterance by mapping every token of the label to a number.
  * Create container base class (audiomate.corpus.assets.Container), that can be used to store arbitrary data per utterance. The audiomate.corpus.assets.FeatureContainer is now an extension of the container, that provides functionality especially for features.
  * Added functions to split utterances and label-lists into multiple parts. (audiomate.corpus.assets.Utterance.split(), audiomate.corpus.assets.LabelList.split())
  * Added audiomate.processing.pipeline.AddContext to add context to frames, using previous and subsequent frames.
  * Added reader (audiomate.corpus.io.MailabsReader) and downloader (audiomate.corpus.io.MailabsDownloader) for the M-AILABS Speech Dataset.
  + Fixes
  * [#58] Keep track of number of samples per frame and between frames. Now the correct values will be stored in a Feature-Container, if the processor implements it correctly.
  * [#72] Fix bug, when reading samples from utterance, using a specific duration, while the utterance end is not defined.
* Tue Nov  6 2018 Jan Engelhardt <jengelh@inai.de>
- Join first and second sentence; trim conjecture.
* Fri Nov  2 2018 Todd R <toddrme2178@gmail.com>
- Initial version
